(***********************************************************************)
(*                                                                     *)
(*                             Pio (OCaml)                             *)
(*                                                                     *)
(*                    Polyglot Input/Output Library                    *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2005-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: options_pio.ml,v 1.15 2014/02/25 17:03:35 fclement Exp $ *)

(* Report/debug flags and warning/error messages. *)

module Cmd_opt = Ucommand_option;;

let purpose = Udebug.Library;;
let software_name = "Pio/OCaml";;
let key_prefixes = Udebug.make_key_prefixes software_name;;

let pf = Udebug.make_printing_facilities purpose software_name key_prefixes
;;

(* Binary/ASCII modes. *)

let ({ Uaref.get_tflag = get_binary_mode; toggle_tflag = set_binary_mode; _ },
     { Uaref.get_tflag = get_ascii_mode; toggle_tflag = set_ascii_mode; _ }) =
  Uaref.make_antonymic_toggle_flags true;;

let option_ascii =
  {
   Cmd_opt.key = Printf.sprintf "%s-ascii" key_prefixes.Udebug.long;
   spec = Arg.Unit set_ascii_mode;
   doc =
     Printf.sprintf
       "\n\
       \tTurn %s ascii mode on.\n\
       \tFloating-point numbers are written using an ascii \
         human-readable format.\n\
       \tThis mode is exclusive to binary mode. Default is %b."
       software_name (get_ascii_mode ());
  }

and option_binary =
  {
   Cmd_opt.key = Printf.sprintf "%s-binary" key_prefixes.Udebug.long;
   spec = Arg.Unit set_binary_mode;
   doc =
     Printf.sprintf
       "\n\
       \tTurn %s binary mode on.\n\
       \tFloating-point numbers are written using a compact binary \
         format.\n\
       \tThis mode is exclusive to ascii mode. Default is %b."
       software_name (get_binary_mode ());
  }
;;

(* Command-line options. *)

let regular_opt rco =
  Cmd_opt.with_auto_short_key
    (Cmd_opt.with_auto_gnu_key
       (Cmd_opt.of_regular rco))
;;

let library_add_all l = Cmd_opt.library_add_all (Ulist.map regular_opt l);;

let add_options () = library_add_all [ option_ascii; option_binary; ];;

add_options ();;
