CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                            Pio (Fortran)                            C
C                                                                     C
C                    Polyglot Input/Output Library                    C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright 2005-2014 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C $Id: fetch_value.fpp,v 1.2 2014/01/10 19:22:10 fclement Exp $

C     
C     Routines to fetch data in the low-level memory from their number.
C     
      
#include "pio_constants.h"
      
      subroutine rand_fetch_loc_len(sbr, io, i, loc, len)
C     Get bounds in memory of the ith value.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io, i
      
C     Output arguments.
      integer loc, len
      
C     Local variables.
      integer bv, ev
      
C     External functions.
      integer fetch_value_begin, fetch_value_end
      
      bv = fetch_value_begin(sbr, io, i)
      ev = fetch_value_end(sbr, io, i)
      
      loc = bv
      len = ev - bv
      
      return
      end
      
      
      subroutine fetch_communication_name(sbr, io, name, nlen)
C     Fetches the communication name, ie the task name or the service
C     name, an ident, from the memory and writes it into string name of
C     length nlen.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io
      
C     Input/output argument.
      integer nlen
      
C     Output argument.
      character name*(*)
      
C     Local variables.
      integer bn, en, len
      
C     External functions.
      integer fetch_communication_name_begin
      integer fetch_communication_name_end
      
      bn = fetch_communication_name_begin(sbr, io)
      en = fetch_communication_name_end(sbr, io)
      len = en - bn
      
      if (len .le. nlen) then
         call rand_fetch_string(sbr, io, bn, name, 1, len)
         nlen = len
      else
         call error_too_long_string_value(sbr, nlen, len)
      endif
      
      return
      end
      
      
      subroutine rand_fetch_string_value(sbr, io, i, sdatum, slen)
C     Fetches the ith value, a string, from the memory and writes it
C     into string sdatum of length slen.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io, i
      
C     Input/output argument.
      integer slen
      
C     Output argument.
      character sdatum*(*)
      
C     Local variables.
      integer loc, len, nl, lenv(MAX_STRING_ITEMS)
      
      call rand_fetch_loc_len(sbr, io, i, loc, len)
      call fetch_value_lengths(sbr, io, i, nl, lenv)
      
      if (nl .ne. 1) then
         call error_wrong_dimension(sbr, 1, nl)
      endif
      
      if (lenv(1) .ne. len) then
         call error_incoherent_string_length(sbr, len, lenv(1))
      endif
      
      if (len .le. slen) then
         call rand_fetch_string(sbr, io, loc, sdatum, 1, len)
         slen = lenv(1)
      else
         call error_too_long_string_value(sbr, slen, len)
      endif
      
      return
      end
      
      
      integer function rand_fetch_int_value
     +     (sbr, io, i, j, k, dim1, l, tup)
C     Fetches an integer from the memory, the lth tuple component out of
C     tup of the kth vector component out of dim1 of the jth line of the
C     ith value.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io, i, j, k, dim1, l, tup
      
C     Local variables.
      integer loc_i, len_i, shift_jkl, loc_ijkl, good, bad
      
C     External function.
      integer rand_fetch_int
      
      call rand_fetch_loc_len(sbr, io, i, loc_i, len_i)
      shift_jkl = (j - 1)*dim1 + (k - 1)*tup + l - 1
      loc_ijkl = loc_i + shift_jkl*INT_SIZE
      
C     We test that loc_ijkl + INT_SIZE <= loc_i + len_i.
      if (len_i .ge. (shift_jkl + 1)*INT_SIZE) then
         rand_fetch_int_value = rand_fetch_int(sbr, io, loc_ijkl)
      else
         good = loc_i + len_i
         bad = loc_ijkl + INT_SIZE
         call error_out_of_value_memory_access(sbr, good, bad)
      endif
      
      return
      end
      
      
      FLOAT function rand_fetch_float_value
     +     (sbr, io, i, j, k, dim1, l, tup)
C     Fetches a float from the memory, the lth tuple component out of
C     tup of the kth vector component out of dim1 of the jth line of the
C     ith value.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io, i, j, k, dim1, l, tup
      
C     Local variables.
      integer loc_i, len_i, shift_jkl, loc_ijkl, good, bad
      
C     External function.
      FLOAT rand_fetch_float
      
      call rand_fetch_loc_len(sbr, io, i, loc_i, len_i)
      shift_jkl = (j - 1)*dim1 + (k - 1)*tup + l - 1
      loc_ijkl = loc_i + shift_jkl*FLOAT_SIZE
      
      if (len_i .ge. (shift_jkl + 1)*FLOAT_SIZE) then
         rand_fetch_float_value = rand_fetch_float(sbr, io, loc_ijkl)
      else
         good = loc_i + len_i
         bad = loc_ijkl + FLOAT_SIZE
         call error_out_of_value_memory_access(sbr, good, bad)
      endif
      
      return
      end
      
      
      subroutine rand_fetch_string_compound_value
     +     (sbr, io, i, n, vlen, svdatum)
C     Fetches the ith value, a string compound value, from the memory
C     and writes it into string array svdatum.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io, i, n
      
C     Input/output argument.
      integer vlen(*)
      
C     Output argument.
      character svdatum(*)*(*)
      
C     Local variables.
      integer loc, len, nl, lenv(MAX_STRING_ITEMS), tlen, j
      
C     External function.
      logical pio_get_debug_mode
      
      call rand_fetch_loc_len(sbr, io, i, loc, len)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] ',
     +        'In rand_fetch_string_compound_value: ',
     +        ' loc = ', loc, ', len = ', len
      endif
      
      call fetch_value_lengths(sbr, io, i, nl, lenv)
      
      if (nl .ne. n) then
         call error_wrong_size(sbr, n, nl)
      endif
      
      tlen = 0
      do j = 1, n
         tlen = tlen + lenv(j)
      enddo
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] ',
     +        'In rand_fetch_string_compound_value: ',
     +        ' tlen = ', tlen
      endif
      
      do j = 1, n
         if (lenv(j) .gt. vlen(j)) then
            call error_too_long_string_value(sbr, vlen(j), lenv(j))
         else
            vlen(j) = lenv(j)
         endif
      enddo
      
      if (len .le. tlen) then
         call rand_fetch_string_vect(sbr, io, loc, svdatum, vlen, 1, n)
      else
         call error_incoherent_string_length(sbr, len, tlen)
      endif
      
      return
      end
      
      
      subroutine rand_fetch_int_compound_value(sbr, io, i, n, ivdatum)
C     Fetches the ith value, an integer compound value of size n, from
C     the memory and writes it into integer array ivdatum of length n.
C     On output, n is the actual size read.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io, i
      
C     Input/output argument.
      integer n
      
C     Output argument.
      integer ivdatum(*)
      
C     Local variables.
      integer loc, len, p
      
      call rand_fetch_loc_len(sbr, io, i, loc, len)
      
      if (len .le. n * INT_SIZE) then
         p = len / INT_SIZE
         call rand_fetch_int_vect(sbr, io, loc, ivdatum, 1, p)
         n = p
      else      
         call error_wrong_int_compound_size(sbr, n, len)
      endif
      
      return
      end
      
      
      subroutine rand_fetch_float_compound_value(sbr, io, i, n, fvdatum)
C     Fetches the ith value, a float compound value of size n, from the
C     memory and writes it into float array fvdatum of length n.
C     On output, n is the actual size read.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io, i
      
C     Input/output argument.
      integer n
      
C     Output argument.
      FLOAT fvdatum(*)
      
C     Local variables.
      integer loc, len, p
      
      call rand_fetch_loc_len(sbr, io, i, loc, len)
      
      if (len .le. n * FLOAT_SIZE) then
         p = len / FLOAT_SIZE
         call rand_fetch_float_vect(sbr, io, loc, fvdatum, 1, p)
         n = p
      else
         call error_wrong_float_compound_size(sbr, n, len)
      endif
      
      return
      end
      
      
      subroutine seq_fetch_string_value(sbr, io, sdatum, slen)
C     Fetches the current value, a string, from the memory and writes it
C     into string sdatum.
C     On input of this subroutine, slen is the declared length of string
C     sdatum, and on output, slen is the length of the string value.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io
      
C     Input/output argument.
      integer slen
      
C     Output argument.
      character sdatum*(*)
      
C     Local variable.
      integer i
      
C     External function.
      integer get_fetch_value_number
      
      i = get_fetch_value_number(io)
      
      call rand_fetch_string_value(sbr, io, i, sdatum, slen)
      
      call incr_fetch_value_number(sbr, io)
      
      return
      end
      
      
      integer function seq_fetch_int_value(sbr, io)
C     Fetches the current value, an integer, from the memory.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io
      
C     Local variable.
      integer i
      
C     External functions.
      integer get_fetch_value_number
      integer rand_fetch_int_value
      
      i = get_fetch_value_number(io)
      
      seq_fetch_int_value =
     +     rand_fetch_int_value(sbr, io, i, 1, 1, 1, 1, 1)
      
      call incr_fetch_value_number(sbr, io)
      
      return
      end
      
      
      FLOAT function seq_fetch_float_value(sbr, io)
C     Fetches the current value, a float, from the memory.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io
      
C     Local variable.
      integer i
      
C     External functions.
      integer get_fetch_value_number
      FLOAT rand_fetch_float_value
      
      i = get_fetch_value_number(io)
      
      seq_fetch_float_value =
     +     rand_fetch_float_value(sbr, io, i, 1, 1, 1, 1, 1)
      
      call incr_fetch_value_number(sbr, io)
      
      return
      end
      
      
      subroutine seq_fetch_string_compound_value
     +     (sbr, io, n, vlen, svdatum)
C     Fetches the current value, a string compound value, from the
C     memory and writes it into string array svdatum.
C     On input of this subroutine, n is the declared size of the string
C     array svdatum and vlen is the array of declared lengths of its
C     components (all equal), and on output, n is the size of the string
C     compound value and vlen is the array of lengths of its components.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io
      
C     Input/output arguments.
      integer n, vlen(*)
      
C     Output argument.
      character svdatum(*)*(*)
      
C     Local variable.
      integer i
      
C     External function.
      integer get_fetch_value_number
      
      i = get_fetch_value_number(io)
      
      call rand_fetch_string_compound_value
     +     (sbr, io, i, n, vlen, svdatum)
      
      call incr_fetch_value_number(sbr, io)
      
      return
      end
      
      
      subroutine seq_fetch_int_compound_value(sbr, io, n, ivdatum)
C     Fetches the current value, an integer compound value of size n,
C     from the memory and writes it into integer array ivdatum.
C     On input of this subroutine, n is the declared size of the integer
C     array ivdatum, and on output, n is the size of the integer
C     compound value.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io
      
C     Input/output argument.
      integer n
      
C     Output argument.
      integer ivdatum(*)
      
C     Local variable.
      integer i
      
C     External function.
      integer get_fetch_value_number
      
      i = get_fetch_value_number(io)
      
      call rand_fetch_int_compound_value(sbr, io, i, n, ivdatum)
      
      call incr_fetch_value_number(sbr, io)
      
      return
      end
      
      
      subroutine seq_fetch_float_compound_value(sbr, io, n, fvdatum)
C     Fetches the current value, a float compound value of size n, from
C     the memory and writes it into float array fvdatum.
C     On input of this subroutine, n is the declared size of the float
C     array fvdatum, and on output, n is the size of the float compound
C     value.
      
      implicit none
      
C     Input arguments.
      character sbr*(*)
      integer io
      
C     Input/output argument.
      integer n
      
C     Output argument.
      FLOAT fvdatum(*)
      
C     Local variable.
      integer i
      
C     External function.
      integer get_fetch_value_number
      
      i = get_fetch_value_number(io)
      
      call rand_fetch_float_compound_value(sbr, io, i, n, fvdatum)
      
      call incr_fetch_value_number(sbr, io)
      
      return
      end
